Crate agglayer_bincode

Crate agglayer_bincode 

Structs

Codec
Bincode codec with opinionated settings.

Enums

ErrorKind
The kind of error that can be produced during a serialization or deserialization.

Traits

Options
A configuration builder trait whose options Bincode will use while serializing and deserializing.

Functions

contracts
Create a bincode coded with settings used by smart contract verifiers.
default
Create a bincode codec with default agglayer settings.
sp1_compatible
Create a bincode codec with settings compatible with SP1 payload encoding.
sp1v4Deprecated
Create a bincode codec with settings used by sp1.

Type Aliases

Error
An error that can be produced during (de)serializing.
Result
The result of a serialization or deserialization operation.